#[repr(u32)]pub enum cuvsBinaryQuantizerThreshold {
ZERO = 0,
MEAN = 1,
SAMPLING_MEDIAN = 2,
}Expand description
@defgroup preprocessing_c_binary C API for Binary Quantizer @{ / /** @brief In the cuvsBinaryQuantizerTransform function, a bit is set if the corresponding element in the dataset vector is greater than the corresponding element in the threshold vector. The mean and sampling_median thresholds are calculated separately for each dimension.
Variants