cuvsCagraGraphBuildAlgo

Enum cuvsCagraGraphBuildAlgo 

#[repr(u32)]
pub enum cuvsCagraGraphBuildAlgo { AUTO_SELECT = 0, IVF_PQ = 1, NN_DESCENT = 2, ITERATIVE_CAGRA_SEARCH = 3, ACE = 4, }
@brief Enum to denote which ANN algorithm is used to build CAGRA graph

Variants



AUTO_SELECT = 0



IVF_PQ = 1



NN_DESCENT = 2



ACE = 4

Experimental, use ACE (Augmented Core Extraction) to build the graph. ACE partitions the dataset into core and augmented partitions and builds a sub-index for each partition. This enables building indices for datasets too large to fit in GPU or host memory. See cuvsAceParams for more details about the ACE algorithm and its parameters.