#[repr(u32)]pub enum cuvsNNDescentDistCompDtype {
NND_DIST_COMP_AUTO = 0,
NND_DIST_COMP_FP32 = 1,
NND_DIST_COMP_FP16 = 2,
}Expand description
@brief Dtype to use for distance computation
NND_DIST_COMP_AUTO: Automatically determine the best dtype for distance computation based on the dataset dimensions.NND_DIST_COMP_FP32: Use fp32 distance computation for better precision at the cost of performance and memory usage.NND_DIST_COMP_FP16: Use fp16 distance computation.
Variants