pub unsafe extern "C" fn cuvsBinaryQuantizerTransformWithParams(
res: cuvsResources_t,
quantizer: cuvsBinaryQuantizer_t,
dataset: *mut DLManagedTensor,
out: *mut DLManagedTensor,
) -> cuvsError_tExpand description
@brief Applies binary quantization transform to the given dataset
This applies binary quantization to a dataset, changing any values that are larger than the threshold specified in the param to a bitwise 1. This is useful for searching with the BitwiseHamming distance type.
@param[in] res raft resource @param[in] quantizer binary quantizer @param[in] dataset a row-major host or device matrix to transform @param[out] out a row-major host or device matrix to store transformed data