cuvsCagraDeserialize

Function cuvsCagraDeserialize 

pub unsafe extern "C" fn cuvsCagraDeserialize(
    res: cuvsResources_t,
    filename: *const c_char,
    index: cuvsCagraIndex_t,
) -> cuvsError_t
Load index from file.

Experimental, both the API and the serialization format are subject to change.

@param[in] res cuvsResources_t opaque C handle @param[in] filename the name of the file that stores the index @param[inout] index cuvsCagraIndex_t CAGRA index loaded from disk. This index needs to be already created with cuvsCagraIndexCreate.