pub unsafe extern "C" fn cuvsCagraIndexGetGraph(
index: cuvsCagraIndex_t,
graph: *mut DLManagedTensor,
) -> cuvsError_tExpand description
@brief Returns a view of the CAGRA graph
This function returns a non-owning view of the CAGRA graph. The output will be referencing device memory that is directly used in CAGRA, without copying the graph at all. This means that the output is only valid as long as the CAGRA index is alive, and once cuvsCagraIndexDestroy is called on the cagra index - the returned graph view will be invalid.
Note that the DLManagedTensor graph returned will have an associated ‘deleter’ function that must be called when the graph is no longer needed. This will free up host memory that stores the metadata for the graph view.
@param[in] index CAGRA index @param[out] graph the output knn graph. @return cuvsError_t