cuvsCagraSerialize

Function cuvsCagraSerialize 

pub unsafe extern "C" fn cuvsCagraSerialize(
    res: cuvsResources_t,
    filename: *const c_char,
    index: cuvsCagraIndex_t,
    include_dataset: bool,
) -> cuvsError_t
@defgroup cagra_c_index_serialize CAGRA C-API serialize functions @{ / /** Save the index to file.

Experimental, both the API and the serialization format are subject to change.

@code{.c} #include <cuvs/neighbors/cagra.h>

// Create cuvsResources_t cuvsResources_t res; cuvsError_t res_create_status = cuvsResourcesCreate(&res);

// create an index with cuvsCagraBuild cuvsCagraSerialize(res, “/path/to/index”, index, true); @endcode

@param[in] res cuvsResources_t opaque C handle @param[in] filename the file name for saving the index @param[in] index CAGRA index @param[in] include_dataset Whether or not to write out the dataset to the file.