cuvsIvfFlatDeserialize

Function cuvsIvfFlatDeserialize 

pub unsafe extern "C" fn cuvsIvfFlatDeserialize(
    res: cuvsResources_t,
    filename: *const c_char,
    index: cuvsIvfFlatIndex_t,
) -> cuvsError_t
Load index from file.

Experimental, both the API and the serialization format are subject to change.

@param[in] res cuvsResources_t opaque C handle @param[in] filename the name of the file that stores the index @param[out] index IVF-Flat index loaded disk