pub unsafe extern "C" fn cuvsIvfPqExtend(
res: cuvsResources_t,
new_vectors: *mut DLManagedTensor,
new_indices: *mut DLManagedTensor,
index: cuvsIvfPqIndex_t,
) -> cuvsError_tExpand description
@defgroup ivf_pq_c_index_extend IVF-PQ index extend @{ / /** @brief Extend the index with the new data.
@param[in] res cuvsResources_t opaque C handle @param[in] new_vectors DLManagedTensor* the new vectors to add to the index @param[in] new_indices DLManagedTensor* vector of new indices for the new vectors @param[inout] index IVF-PQ index to be extended @return cuvsError_t