cuvsIvfPqIndexGetCenters

Function cuvsIvfPqIndexGetCenters 

pub unsafe extern "C" fn cuvsIvfPqIndexGetCenters(
    index: cuvsIvfPqIndex_t,
    centers: *mut DLManagedTensor,
) -> cuvsError_t
@brief Get the cluster centers corresponding to the lists in the original space

@param[in] index cuvsIvfPqIndex_t Built Ivf-Pq index @param[out] centers Output tensor that will be populated with a non-owning view of the data @return cuvsError_t