cuvsIvfPqIndexGetListIndices

Function cuvsIvfPqIndexGetListIndices 

pub unsafe extern "C" fn cuvsIvfPqIndexGetListIndices(
    index: cuvsIvfPqIndex_t,
    label: u32,
    out_labels: *mut DLManagedTensor,
) -> cuvsError_t
@brief Get the indices of each vector in a ivf-pq list

@param[in] index cuvsIvfPqIndex_t Built Ivf-Pq index @param[in] label The id of the list (cluster) to decode. @param[out] out_labels output tensor that will be populated with a non-owning view of the data @return cuvsError_t