pub unsafe extern "C" fn cuvsIvfPqIndexGetPqDim(
index: cuvsIvfPqIndex_t,
pq_dim: *mut i64,
) -> cuvsError_tExpand description
Get the dimensionality of an encoded vector after compression by PQ.
pub unsafe extern "C" fn cuvsIvfPqIndexGetPqDim(
index: cuvsIvfPqIndex_t,
pq_dim: *mut i64,
) -> cuvsError_tGet the dimensionality of an encoded vector after compression by PQ.