pub unsafe extern "C" fn cuvsIvfPqIndexGetPqLen(
index: cuvsIvfPqIndex_t,
pq_len: *mut i64,
) -> cuvsError_tExpand description
Get the Dimensionality of a subspace, i.e. the number of vector components mapped to a subspace
pub unsafe extern "C" fn cuvsIvfPqIndexGetPqLen(
index: cuvsIvfPqIndex_t,
pq_len: *mut i64,
) -> cuvsError_tGet the Dimensionality of a subspace, i.e. the number of vector components mapped to a subspace