cuvsIvfPqIndexUnpackContiguousListData

Function cuvsIvfPqIndexUnpackContiguousListData 

pub unsafe extern "C" fn cuvsIvfPqIndexUnpackContiguousListData(
    res: cuvsResources_t,
    index: cuvsIvfPqIndex_t,
    out_codes: *mut DLManagedTensor,
    label: u32,
    offset: u32,
) -> cuvsError_t
@brief Unpack n_rows consecutive PQ encoded vectors of a single list (cluster) in the compressed index starting at given offset, not expanded to one code per byte. Each code in the output buffer occupies ceildiv(index.pq_dim() * index.pq_bits(), 8) bytes.

@param[in] res raft resource @param[in] index cuvsIvfPqIndex_t Built Ivf-Pq index @param[out] out_codes the destination buffer [n_rows, ceildiv(index.pq_dim() * index.pq_bits(), 8)]. The length n_rows defines how many records to unpack, offset + n_rows must be smaller than or equal to the list size. This DLManagedTensor must already point to allocated device memory @param[in] label The id of the list (cluster) to decode. @param[in] offset How many records in the list to skip.