cuvsMultiGpuResourcesSetMemoryPool

Function cuvsMultiGpuResourcesSetMemoryPool 

pub unsafe extern "C" fn cuvsMultiGpuResourcesSetMemoryPool(
    res: cuvsResources_t,
    percent_of_free_memory: c_int,
) -> cuvsError_t
@brief Set a memory pool on all devices managed by the multi-GPU resources

@param[in] res cuvsResources_t opaque C handle for multi-GPU resources @param[in] percent_of_free_memory Percent of free memory to allocate for the pool @return cuvsError_t