cuvsProductQuantizerGetPqBits

Function cuvsProductQuantizerGetPqBits 

pub unsafe extern "C" fn cuvsProductQuantizerGetPqBits(
    quantizer: cuvsProductQuantizer_t,
    pq_bits: *mut u32,
) -> cuvsError_t
@brief Get the bit length of the vector element after compression by PQ.

@param[in] quantizer product quantizer @param[out] pq_bits bit length of the vector element after compression by PQ