pub unsafe extern "C" fn cuvsProductQuantizerInverseTransform(
res: cuvsResources_t,
quantizer: cuvsProductQuantizer_t,
pq_codes: *mut DLManagedTensor,
out: *mut DLManagedTensor,
vq_labels: *mut DLManagedTensor,
) -> cuvsError_tExpand description
@brief Applies product quantization inverse transform to the given quantized codes
This applies product quantization inverse transform to the given quantized codes.
@param[in] res raft resource @param[in] quantizer product quantizer @param[in] pq_codes a row-major device matrix of quantized codes @param[out] out a row-major device matrix to store the original data @param[out] vq_labels a device vector containing the VQ labels when VQ is used. Optional, can be NULL.