pub unsafe extern "C" fn cuvsRMMHostFree(
ptr: *mut c_void,
bytes: usize,
) -> cuvsError_tExpand description
@brief Deallocates pinned memory on the host using RMM @param[in] ptr Pointer to allocated host memory to free @param[in] bytes Size in bytes to deallocate @return cuvsError_t