pub unsafe extern "C" fn cuvsRMMPoolMemoryResourceEnable(
initial_pool_size_percent: c_int,
max_pool_size_percent: c_int,
managed: bool,
) -> cuvsError_tExpand description
@brief Switches the working memory resource to use the RMM pool memory resource, which will bypass unnecessary synchronizations by allocating a chunk of device memory up front and carving that up for temporary memory allocations within algorithms. Be aware that this function will change the memory resource for the whole process and the new memory resource will be used until explicitly changed.
@param[in] initial_pool_size_percent The initial pool size as a percentage of the total available memory @param[in] max_pool_size_percent The maximum pool size as a percentage of the total available memory @param[in] managed Whether to use a managed memory resource as upstream resource or not @return cuvsError_t