cuvsScalarQuantizerInverseTransform

Function cuvsScalarQuantizerInverseTransform 

pub unsafe extern "C" fn cuvsScalarQuantizerInverseTransform(
    res: cuvsResources_t,
    quantizer: cuvsScalarQuantizer_t,
    dataset: *mut DLManagedTensor,
    out: *mut DLManagedTensor,
) -> cuvsError_t
@brief Perform inverse quantization step on previously quantized dataset

Note that depending on the chosen data types train dataset the conversion is not lossless.

@param[in] res raft resource @param[in] quantizer a scalar quantizer @param[in] dataset a row-major host or device matrix @param[out] out a row-major host or device matrix