#[repr(C)]pub struct cuvsBinaryQuantizer {
pub addr: usize,
pub dtype: DLDataType,
}Expand description
@brief Defines and stores threshold for quantization upon training
The quantization is performed by a linear mapping of an interval in the float data type to the full range of the quantized int type.
Fields
addr: usizedtype: DLDataTypeTrait Implementations
Sourceimpl Clone for cuvsBinaryQuantizer
impl Clone for cuvsBinaryQuantizer
Sourcefn clone(&self) -> cuvsBinaryQuantizer
fn clone(&self) -> cuvsBinaryQuantizer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for cuvsBinaryQuantizer