#[repr(C)]pub struct cuvsCagraCompressionParams {
pub pq_bits: u32,
pub pq_dim: u32,
pub vq_n_centers: u32,
pub kmeans_n_iters: u32,
pub vq_kmeans_trainset_fraction: f64,
pub pq_kmeans_trainset_fraction: f64,
}Expand description
Parameters for VPQ compression.
Fields
pq_bits: u32The bit length of the vector element after compression by PQ.
Possible values: [4, 5, 6, 7, 8].
Hint: the smaller the ‘pq_bits’, the smaller the index size and the better the search performance, but the lower the recall.
pq_dim: u32The dimensionality of the vector after compression by PQ. When zero, an optimal value is selected using a heuristic.
TODO: at the moment dim must be a multiple pq_dim.
vq_n_centers: u32Vector Quantization (VQ) codebook size - number of “coarse cluster centers”. When zero, an optimal value is selected using a heuristic.
kmeans_n_iters: u32The number of iterations searching for kmeans centers (both VQ & PQ phases).
vq_kmeans_trainset_fraction: f64The fraction of data to use during iterative kmeans building (VQ phase). When zero, an optimal value is selected using a heuristic.
pq_kmeans_trainset_fraction: f64The fraction of data to use during iterative kmeans building (PQ phase). When zero, an optimal value is selected using a heuristic.