cuvsCagraExtendParams

Struct cuvsCagraExtendParams 

#[repr(C)]
pub struct cuvsCagraExtendParams { pub max_chunk_size: u32, }
@defgroup cagra_c_extend_params C API for CUDA ANN Graph-based nearest neighbor search @{ / /** @brief Supplemental parameters to extend CAGRA Index

Fields

max_chunk_size: u32

The additional dataset is divided into chunks and added to the graph. This is the knob to adjust the tradeoff between the recall and operation throughput. Large chunk sizes can result in high throughput, but use more working memory (O(max_chunk_size*degree^2)). This can also degrade recall because no edges are added between the nodes in the same chunk. Auto select when 0.