cuvsKMeansParams

Struct cuvsKMeansParams 

#[repr(C)]
pub struct cuvsKMeansParams {
Show 13 fields pub metric: cuvsDistanceType, pub n_clusters: c_int, pub init: cuvsKMeansInitMethod, pub max_iter: c_int, pub tol: f64, pub n_init: c_int, pub oversampling_factor: f64, pub batch_samples: c_int, pub batch_centroids: c_int, pub inertia_check: bool, pub hierarchical: bool, pub hierarchical_n_iters: c_int, pub streaming_batch_size: i64,
}
@brief Hyper-parameters for the kmeans algorithm

Fields

metric: cuvsDistanceTypen_clusters: c_int

The number of clusters to form as well as the number of centroids to generate (default:8).

init: cuvsKMeansInitMethod

Method for initialization, defaults to k-means++:

  • cuvsKMeansInitMethod::KMeansPlusPlus (k-means++): Use scalable k-means++ algorithm to select the initial cluster centers.
  • cuvsKMeansInitMethod::Random (random): Choose ‘n_clusters’ observations (rows) at random from the input data for the initial centroids.
  • cuvsKMeansInitMethod::Array (ndarray): Use ‘centroids’ as initial cluster centers.
max_iter: c_int

Maximum number of iterations of the k-means algorithm for a single run.

tol: f64

Relative tolerance with regards to inertia to declare convergence.

n_init: c_int

Number of instance k-means algorithm will be run with different seeds.

oversampling_factor: f64

Oversampling factor for use in the k-means|| algorithm

batch_samples: c_int

batch_samples and batch_centroids are used to tile 1NN computation which is useful to optimize/control the memory footprint Default tile is [batch_samples x n_clusters] i.e. when batch_centroids is 0 then don’t tile the centroids

batch_centroids: c_int

if 0 then batch_centroids = n_clusters

inertia_check: bool

Check inertia during iterations for early convergence.

hierarchical: bool

Whether to use hierarchical (balanced) kmeans or not

hierarchical_n_iters: c_int

For hierarchical k-means , defines the number of training iterations

streaming_batch_size: i64

Number of samples to process per GPU batch for the batched (host-data) API. When set to 0, defaults to n_samples (process all at once).