#[repr(C)]pub struct cuvsPcaParams {
pub n_components: c_int,
pub copy: bool,
pub whiten: bool,
pub algorithm: cuvsPcaSolver,
pub tol: f32,
pub n_iterations: c_int,
}Expand description
@brief Parameters for PCA decomposition.
Fields
n_components: c_intNumber of principal components to keep.
copy: boolIf false, data passed to fit are overwritten and running fit(X).transform(X) will not yield the expected results; use fit_transform(X) instead.
whiten: boolWhen true the component vectors are multiplied by the square root of n_samples and then divided by the singular values to ensure uncorrelated outputs with unit component-wise variances.
algorithm: cuvsPcaSolverSolver algorithm to use.
tol: f32Tolerance for singular values (used by Jacobi solver).
n_iterations: c_intNumber of iterations for the power method (Jacobi solver).