#[repr(C)]pub struct cuvsProductQuantizer {
pub addr: usize,
pub dtype: DLDataType,
}Expand description
@brief Defines and stores product quantizer upon training
The quantization is performed by a linear mapping of an interval in the float data type to the full range of the quantized int type.
Fields
addr: usizedtype: DLDataTypeTrait Implementations
Sourceimpl Clone for cuvsProductQuantizer
impl Clone for cuvsProductQuantizer
Sourcefn clone(&self) -> cuvsProductQuantizer
fn clone(&self) -> cuvsProductQuantizer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for cuvsProductQuantizer