#[repr(C)]pub struct cuvsScalarQuantizer {
pub min_: f64,
pub max_: f64,
}Expand description
@brief Defines and stores scalar for quantisation upon training
The quantization is performed by a linear mapping of an interval in the float data type to the full range of the quantized int type.
Fields
min_: f64max_: f64Trait Implementations
Sourceimpl Clone for cuvsScalarQuantizer
impl Clone for cuvsScalarQuantizer
Sourcefn clone(&self) -> cuvsScalarQuantizer
fn clone(&self) -> cuvsScalarQuantizer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for cuvsScalarQuantizer