#[repr(C)]pub struct cuvsTieredIndexParams {
pub metric: cuvsDistanceType,
pub algo: cuvsTieredIndexANNAlgo,
pub min_ann_rows: i64,
pub create_ann_index_on_extend: bool,
pub cagra_params: cuvsCagraIndexParams_t,
pub ivf_flat_params: cuvsIvfFlatIndexParams_t,
pub ivf_pq_params: cuvsIvfPqIndexParams_t,
}Expand description
@defgroup tiered_c_index_params Tiered Index build parameters @{ / /** @brief Supplemental parameters to build a TieredIndex
Fields
metric: cuvsDistanceTypeDistance type.
algo: cuvsTieredIndexANNAlgoThe type of ANN algorithm we are using
min_ann_rows: i64The minimum number of rows necessary in the index to create an ann index
create_ann_index_on_extend: boolWhether or not to create a new ann index on extend, if the number of rows in the incremental (bfknn) portion is above min_ann_rows
cagra_params: cuvsCagraIndexParams_tOptional parameters for building a cagra index
ivf_flat_params: cuvsIvfFlatIndexParams_tOptional parameters for building a ivf_flat index
ivf_pq_params: cuvsIvfPqIndexParams_tOptional parameters for building a ivf-pq index