pub unsafe extern "C" fn cuvsDeviceIdGet(
res: cuvsResources_t,
device_id: *mut c_int,
) -> cuvsError_tExpand description
@brief Get the id of the device associated with this cuvsResources_t
@param[in] res cuvsResources_t opaque C handle @param[out] device_id int the id of the device associated with res @return cuvsError_t