pub unsafe extern "C" fn cuvsIvfFlatIndexGetCenters(
index: cuvsIvfFlatIndex_t,
centers: *mut DLManagedTensor,
) -> cuvsError_tExpand description
@brief Get the cluster centers corresponding to the lists [n_lists, dim]
@param[in] index cuvsIvfFlatIndex_t Built Ivf-Flat Index @param[out] centers Preallocated array on host or device memory to store output, [n_lists, dim] @return cuvsError_t