pub unsafe extern "C" fn cuvsIvfFlatSerialize(
res: cuvsResources_t,
filename: *const c_char,
index: cuvsIvfFlatIndex_t,
) -> cuvsError_tExpand description
@defgroup ivf_flat_c_index_serialize IVF-Flat C-API serialize functions @{ / /** Save the index to file.
Experimental, both the API and the serialization format are subject to change.
@code{.cpp} #include <cuvs/neighbors/ivf_flat.h>
// Create cuvsResources_t cuvsResources_t res; cuvsError_t res_create_status = cuvsResourcesCreate(&res);
// create an index with cuvsIvfFlatBuild
cuvsIvfFlatSerialize(res, “/path/to/index”, index, true);
@endcode
@param[in] res cuvsResources_t opaque C handle @param[in] filename the file name for saving the index @param[in] index IVF-Flat index