pub unsafe extern "C" fn cuvsIvfPqIndexGetCentersPadded(
index: cuvsIvfPqIndex_t,
centers: *mut DLManagedTensor,
) -> cuvsError_tExpand description
@brief Get the padded cluster centers [n_lists, dim_ext] where dim_ext = round_up(dim + 1, 8)
This returns the full padded centers as a contiguous array, suitable for use with cuvsIvfPqBuildPrecomputed.
@param[in] index cuvsIvfPqIndex_t Built Ivf-Pq index @param[out] centers Output tensor that will be populated with a non-owning view of the data @return cuvsError_t