pub unsafe extern "C" fn cuvsMatrixSliceRows(
res: cuvsResources_t,
src: *mut DLManagedTensor,
start: i64,
end: i64,
dst: *mut DLManagedTensor,
) -> cuvsError_tExpand description
@brief Slices rows from a matrix
@param[in] res cuvsResources_t opaque C handle @param[in] src Pointer to DLManagedTensor to copy @param[in] start First row index to include in the output @param[in] end Last row index to include in the output @param[out] dst Pointer to DLManagedTensor to receive slice from matrix