pub unsafe extern "C" fn cuvsVamanaSerialize(
res: cuvsResources_t,
filename: *const c_char,
index: cuvsVamanaIndex_t,
include_dataset: bool,
) -> cuvsError_tExpand description
@brief Save Vamana index to file
Matches the file format used by the DiskANN open-source repository, allowing cross-compatibility.
Serialized Index is to be used by the DiskANN open-source repository for graph search.
@code{.c} // Create cuvsResources_t cuvsResources_t res; cuvsResourcesCreate(&res);
// create an index with cuvsVamanaBuild
cuvsVamanaSerialize(res, “/path/to/index”, index, true);
@endcode
@param[in] res cuvsResources_t opaque C handle @param[in] filename the file prefix for where the index is saved @param[in] index cuvsVamanaIndex_t to serialize @param[in] include_dataset whether to include the dataset in the serialized index @return cuvsError_t