#[repr(C)]pub struct cuvsHnswIndexParams {
pub hierarchy: cuvsHnswHierarchy,
pub ef_construction: c_int,
pub num_threads: c_int,
pub M: usize,
pub metric: cuvsDistanceType,
pub ace_params: cuvsHnswAceParams_t,
}Fields
hierarchy: cuvsHnswHierarchyef_construction: c_intSize of the candidate list during hierarchy construction when hierarchy is CPU
num_threads: c_intNumber of host threads to use to construct hierarchy when hierarchy is CPU or GPU.
When the value is 0, the number of threads is automatically determined to the
maximum number of threads available.
NOTE: When hierarchy is GPU, while the majority of the work is done on the GPU,
initialization of the HNSW index itself and some other work
is parallelized with the help of CPU threads.
M: usizeHNSW M parameter: number of bi-directional links per node (used when building with ACE). graph_degree = m * 2, intermediate_graph_degree = m * 3.
metric: cuvsDistanceTypeDistance type for the index.
ace_params: cuvsHnswAceParams_tOptional: specify ACE parameters for building HNSW index using ACE algorithm. Set to nullptr for default behavior (from_cagra conversion).