#[repr(C)]pub struct cuvsVamanaIndexParams {
pub metric: cuvsDistanceType,
pub graph_degree: u32,
pub visited_size: u32,
pub vamana_iters: f32,
pub alpha: f32,
pub max_fraction: f32,
pub batch_base: f32,
pub queue_size: u32,
pub reverse_batchsize: u32,
}Expand description
@brief Supplemental parameters to build Vamana Index
graph_degree: Maximum degree of graph; corresponds to the R parameter of
Vamana algorithm in the literature.
visited_size: Maximum number of visited nodes per search during Vamana algorithm.
Loosely corresponds to the L parameter in the literature.
vamana_iters: The number of times all vectors are inserted into the graph. If > 1,
all vectors are re-inserted to improve graph quality.
max_fraction: The maximum batch size is this fraction of the total dataset size. Larger
gives faster build but lower graph quality.
alpha: Used to determine how aggressive the pruning will be.
Fields
metric: cuvsDistanceTypeDistance type.
graph_degree: u32Maximum degree of output graph corresponds to the R parameter in the original Vamana literature.
visited_size: u32Maximum number of visited nodes per search corresponds to the L parameter in the Vamana literature
vamana_iters: f32Number of Vamana vector insertion iterations (each iteration inserts all vectors).
alpha: f32Alpha for pruning parameter
max_fraction: f32Maximum fraction of dataset inserted per batch. * Larger max batch decreases graph quality, but improves speed
batch_base: f32Base of growth rate of batch sizes
queue_size: u32Size of candidate queue structure - should be (2^x)-1
reverse_batchsize: u32Max batchsize of reverse edge processing (reduces memory footprint)